==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/management/commands/retrieve_kpn_fax.py <==
# coding: utf-8
"""
.. _retrieve-kpn-fax:

Retrive Kpn Fax Online
=============================

Command per la ricezione di fax dal servizio FaxMessage (KPNQuest) ,
utilizzo::

  python manage.py retrive_kpn_fax
  dj retrive_kpn_fax

:-d: variabile Booleana per cancellare il messaggi una volta recuperati
:-l: variabile Numero per limitare il numero di messaggi recuperare
:-v: variabile Booleana per visualizzare i print
:-b, --backup: backup messages in 
"""


import re
import os
import sys
import email
import tempfile
import datetime
import traceback

from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.conf import settings
from django.core import mail

from optparse import make_option

from jmb.fax.models import Fax, FaxNumber, Device
from jmb.fax import mail2fax, kpn

from django.contrib.auth.models import User



class Command(BaseCommand):
    """Get all messages from configured Host
    """
    help = "Retrieve Kpn Fax."

    option_list = BaseCommand.option_list + (
        make_option('-d', '--delete-messages', action='store_true', default=False,
                    dest='delete_messages', help='Delete Messages'),
        make_option('-D', '--debug', action='store_true', default=False,
                    dest='debug_message', help='Debug Messages - print subject and quit'),
        make_option('-l', '--limit', dest='limit', help='Limit Messages', default=1000),
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
        make_option('--pop', action='store_true', help='Retrieve using pop', default=False),
        make_option('-b', '--backup', action='store_true', dest='backup',
                    help='Keep a backup of retrieved email in %s' % mail2fax.BACKUP_DIR,),
    )

    output_transaction = True

    def handle(self, **options):

        if options['pop']:
            self.retrieve_from_pop(options)
        else:
            if options['filename']:
                msg = email.message_from_file(open(options['filename']))
            else:
                msg = email.message_from_string(sys.stdin.read())
            self.parse_single_message(1, msg, options)
            if options['backup']:
                mail2fax.save_row_message(msg)

    def retrieve_from_pop(self, options):
        
        for device in Device.objects.filter(pop_host__isnull=False,  kpn_password__isnull=False):
            if not device.pop_host:  # ad esempio è stringa vuota...
                continue
            if not device.kpn_password:  # ad esempio è stringa vuota...
                continue

            if options['verbosity'] == '2':
                print "Polling mbox %s " % (device.pop_user,)
                
            messages, pop_instance = mail2fax.get_messages(
                device.pop_host, device.pop_user, device.pop_password, limit=options['limit'],
                dump_dir=mail2fax.BACKUP_DIR if options['backup'] else None
                )

            if options['verbosity'] == '2':
                print "Number of messages: %s " % (len(messages),)
            for j, msg in enumerate(messages):
                if options['verbosity'] == '2':
                    print j
                
                self.parse_single_message(j, msg, options, pop_instance)
                    
            pop_instance.quit()


    def parse_single_message(self, j, msg, options, pop_instance=None):

        try:
            kpn_msg = kpn.KpnMsg(msg)
            if not kpn_msg.subject.startswith('Fax per il numero'):
                return
            
            if options['debug_message']:
                print kpn_msg.subject
                return

            fax, created = kpn_msg.get_or_create(save=True, update=True)
#            print "DBG", fax, id(fax), fax.recipient_number, fax.status, fax.id, created
            if created:
                try:
                    kpn_msg.save_attached_file()
                    kpn_msg.notify()
                except Exception, e:
                    filename = mail2fax.save_row_message(msg, error=True, status=kpn_msg.status)
                    send_error_to_admins(kpn_msg, e, filename, show=True)
                    return
            if pop_instance and options['delete_messages']:
                pop_instance.dele(j+1)

        except Exception, e:
            error_msg = str(e) + "\n" + traceback.format_exc()
            try:
                msg = kpn_msg.notification
                filename = mail2fax.save_row_message(msg, error=True, status=kpn_msg.status)
            except Exception, e: # mail2kpn object has not been created for some reason
                msg = ''
                filename = mail2fax.save_row_message(msg, error=True, status=None) # we don't have a kpn_msg
                
            send_error_to_admins(msg, e, filename, error_msg, show=True)


def send_error_to_admins(msg, e, filename, trace=None, show=True):
    """
    Send an understandable mail msg.

    :param msg: a text message or a kpn_msg
    :param e: the error raised
    :param filename: the filename whete message is saved
    :param trace: the formatted traceback of the interesting error
    """
    try:
        subject = msg.subject
    except:
        emsg = email.message_from_file(open(filename))
        subject = "%s\n%s" % (emsg.get('Subject'), emsg.get_payload())[:1000]
                  
        
    body = '%s\n\n%s\n\nSubject: %s\n\n %s' % (filename, e, subject,
                                               trace or traceback.format_exc())
    mail.mail_admins("KPN retrieval problems", body)
    if show:
        print body

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/management/commands/retrieve_kpn_fax.py <==
# coding: utf-8
"""
.. _retrieve-kpn-fax:

Retrive Kpn Fax Online
=============================

Command per la ricezione di fax dal servizio FaxMessage (KPNQuest) ,
utilizzo::

  python manage.py retrive_kpn_fax
  dj retrive_kpn_fax

:-d: variabile Booleana per cancellare il messaggi una volta recuperati
:-l: variabile Numero per limitare il numero di messaggi recuperare
:-v: variabile Booleana per visualizzare i print
:-b, --backup: backup messages in 
"""


from __future__ import unicode_literals

import re
import os
import sys
import email
import tempfile
import datetime
import traceback

from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.conf import settings
from django.core import mail

from optparse import make_option

from jmb.fax.models import Fax, FaxNumber, Device
from jmb.fax import mail2fax, kpn

from django.contrib.auth.models import User


class Command(BaseCommand):

    """Get all messages from configured Host
    """
    help = "Retrieve Kpn Fax."

    option_list = BaseCommand.option_list + (
        make_option('-d', '--delete-messages', action='store_true', default=False,
                    dest='delete_messages', help='Delete Messages'),
        make_option('-D', '--debug', action='store_true', default=False,
                    dest='debug_message', help='Debug Messages - print subject and quit'),
        make_option('-l', '--limit', dest='limit', help='Limit Messages', default=1000),
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
        make_option('--pop', action='store_true', help='Retrieve using pop', default=False),
        make_option('-b', '--backup', action='store_true', dest='backup',
                    help='Keep a backup of retrieved email in %s' % mail2fax.BACKUP_DIR,),
    )

    output_transaction = True

    def handle(self, **options):

        if options['pop']:
            self.retrieve_from_pop(options)
        else:
            if options['filename']:
                msg = email.message_from_file(open(options['filename']))
            else:
                msg = email.message_from_string(sys.stdin.read())
            self.parse_single_message(1, msg, options)
            if options['backup']:
                mail2fax.save_row_message(msg)

    def retrieve_from_pop(self, options):

        for device in Device.objects.filter(pop_host__isnull=False,  kpn_password__isnull=False, status=1):
            if not device.pop_host:  # ad esempio è stringa vuota...
                continue
            if not device.kpn_password:  # ad esempio è stringa vuota...
                continue

            if options['verbosity'] == '2':
                print("Polling mbox %s " % (device.pop_user,))

            messages, pop_instance = mail2fax.get_messages(
                device.pop_host, device.pop_user, device.pop_password, limit=options['limit'],
                dump_dir=mail2fax.BACKUP_DIR if options['backup'] else None
            )

            if options['verbosity'] == '2':
                print("Number of messages: %s " % (len(messages),))
            for j, msg in enumerate(messages):
                if options['verbosity'] == '2':
                    print(j)

                self.parse_single_message(j, msg, options, pop_instance)

            pop_instance.quit()

    def parse_single_message(self, j, msg, options, pop_instance=None):

        try:
            kpn_msg = kpn.KpnMsg(msg)
            if not kpn_msg.subject.startswith('Fax per il numero'):
                return

            if options['debug_message']:
                print(kpn_msg.subject)
                return

            fax, created = kpn_msg.get_or_create(save=True, update=True)
#            print "DBG", fax, id(fax), fax.recipient_number, fax.status, fax.id, created
            if created:
                try:
                    kpn_msg.save_attached_file()
                    kpn_msg.notify()
                except Exception as e:
                    filename = mail2fax.save_row_message(msg, error=True, status=kpn_msg.status)
                    send_error_to_admins(kpn_msg, e, filename, show=True)
                    return
            if pop_instance and options['delete_messages']:
                pop_instance.dele(j+1)

        except Exception as e:
            error_msg = str(e) + "\n" + traceback.format_exc()
            try:
                msg = kpn_msg.notification
                filename = mail2fax.save_row_message(msg, error=True, status=kpn_msg.status)
            except Exception as e:  # mail2kpn object has not been created for some reason
                msg = ''
                filename = mail2fax.save_row_message(
                    msg, error=True, status=None)  # we don't have a kpn_msg

            send_error_to_admins(msg, e, filename, error_msg, show=True)


def send_error_to_admins(msg, e, filename, trace=None, show=True):
    """
    Send an understandable mail msg.

    :param msg: a text message or a kpn_msg
    :param e: the error raised
    :param filename: the filename whete message is saved
    :param trace: the formatted traceback of the interesting error
    """
    try:
        subject = msg.subject
    except:
        emsg = email.message_from_file(open(filename))
        subject = "%s\n%s" % (emsg.get('Subject'), emsg.get_payload())[:1000]

    body = '%s\n\n%s\n\nSubject: %s\n\n %s' % (filename, e, subject,
                                               trace or traceback.format_exc())
    mail.mail_admins("KPN retrieval problems", body)
    if show:
        print(body)
